@@ -21,7 +21,7 @@ failures = 0
 tests = 0
 errors = 0
 for suite in xml:
-    failures = failures + suite.
+    failures = failures + suite.failures
     tests = tests + suite.tests
     errors = errors + suite.errors
 
